# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ConnectionProfile',
    'ConnectionProfileSettings',
    'ConnectionProfileSigning',
    'FeaturesCapabilities',
    'FeaturesCapabilitiesCreate',
    'FeaturesCapabilitiesCreateLifecycleCreate',
    'FeaturesCapabilitiesImportRules',
    'FeaturesCapabilitiesImportRulesUserCreateAndMatch',
    'FeaturesCapabilitiesImportSettings',
    'FeaturesCapabilitiesImportSettingsSchedule',
    'FeaturesCapabilitiesImportSettingsScheduleFullImport',
    'FeaturesCapabilitiesImportSettingsScheduleIncrementalImport',
    'FeaturesCapabilitiesImportSettingsUsername',
    'FeaturesCapabilitiesUpdate',
    'FeaturesCapabilitiesUpdateLifecycleDeactivate',
    'FeaturesCapabilitiesUpdatePassword',
    'FeaturesCapabilitiesUpdateProfile',
    'OAuthGroupsClaim',
    'OAuthJwk',
    'SamlAcsEndpointsIndex',
    'SamlAttributeStatement',
    'SamlKey',
    'GetConnectionProfileResult',
    'GetFeaturesCapabilitiesResult',
    'GetFeaturesCapabilitiesCreateResult',
    'GetFeaturesCapabilitiesCreateLifecycleCreateResult',
    'GetFeaturesCapabilitiesImportRulesResult',
    'GetFeaturesCapabilitiesImportRulesUserCreateAndMatchResult',
    'GetFeaturesCapabilitiesImportSettingsResult',
    'GetFeaturesCapabilitiesImportSettingsScheduleResult',
    'GetFeaturesCapabilitiesImportSettingsScheduleFullImportResult',
    'GetFeaturesCapabilitiesImportSettingsScheduleIncrementalImportResult',
    'GetFeaturesCapabilitiesImportSettingsUsernameResult',
    'GetFeaturesCapabilitiesUpdateResult',
    'GetFeaturesCapabilitiesUpdateLifecycleDeactivateResult',
    'GetFeaturesCapabilitiesUpdatePasswordResult',
    'GetFeaturesCapabilitiesUpdateProfileResult',
    'GetSamlAttributeStatementResult',
]

@pulumi.output_type
class ConnectionProfile(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "authScheme":
            suggest = "auth_scheme"
        elif key == "clientId":
            suggest = "client_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionProfile. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionProfile.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionProfile.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auth_scheme: _builtins.str,
                 client_id: Optional[_builtins.str] = None,
                 settings: Optional['outputs.ConnectionProfileSettings'] = None,
                 signing: Optional['outputs.ConnectionProfileSigning'] = None,
                 token: Optional[_builtins.str] = None):
        """
        :param _builtins.str auth_scheme: Authentication scheme. Valid values are TOKEN or OAUTH2.
        :param _builtins.str client_id: OAuth2 client ID (required for OAUTH2 auth scheme).
        :param 'ConnectionProfileSettingsArgs' settings: Additional settings for OAuth2 authentication.
        :param 'ConnectionProfileSigningArgs' signing: Signing configuration.
        :param _builtins.str token: Authentication token (required for TOKEN auth scheme).
        """
        pulumi.set(__self__, "auth_scheme", auth_scheme)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if signing is not None:
            pulumi.set(__self__, "signing", signing)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter(name="authScheme")
    def auth_scheme(self) -> _builtins.str:
        """
        Authentication scheme. Valid values are TOKEN or OAUTH2.
        """
        return pulumi.get(self, "auth_scheme")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[_builtins.str]:
        """
        OAuth2 client ID (required for OAUTH2 auth scheme).
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional['outputs.ConnectionProfileSettings']:
        """
        Additional settings for OAuth2 authentication.
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def signing(self) -> Optional['outputs.ConnectionProfileSigning']:
        """
        Signing configuration.
        """
        return pulumi.get(self, "signing")

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[_builtins.str]:
        """
        Authentication token (required for TOKEN auth scheme).
        """
        return pulumi.get(self, "token")


@pulumi.output_type
class ConnectionProfileSettings(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminPassword":
            suggest = "admin_password"
        elif key == "adminUsername":
            suggest = "admin_username"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionProfileSettings. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionProfileSettings.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionProfileSettings.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_password: Optional[_builtins.str] = None,
                 admin_username: Optional[_builtins.str] = None):
        """
        :param _builtins.str admin_password: Admin password for OAuth2.
        :param _builtins.str admin_username: Admin username for OAuth2.
        """
        if admin_password is not None:
            pulumi.set(__self__, "admin_password", admin_password)
        if admin_username is not None:
            pulumi.set(__self__, "admin_username", admin_username)

    @_builtins.property
    @pulumi.getter(name="adminPassword")
    def admin_password(self) -> Optional[_builtins.str]:
        """
        Admin password for OAuth2.
        """
        return pulumi.get(self, "admin_password")

    @_builtins.property
    @pulumi.getter(name="adminUsername")
    def admin_username(self) -> Optional[_builtins.str]:
        """
        Admin username for OAuth2.
        """
        return pulumi.get(self, "admin_username")


@pulumi.output_type
class ConnectionProfileSigning(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "rotationMode":
            suggest = "rotation_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ConnectionProfileSigning. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ConnectionProfileSigning.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ConnectionProfileSigning.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rotation_mode: Optional[_builtins.str] = None):
        """
        :param _builtins.str rotation_mode: Token rotation mode.
        """
        if rotation_mode is not None:
            pulumi.set(__self__, "rotation_mode", rotation_mode)

    @_builtins.property
    @pulumi.getter(name="rotationMode")
    def rotation_mode(self) -> Optional[_builtins.str]:
        """
        Token rotation mode.
        """
        return pulumi.get(self, "rotation_mode")


@pulumi.output_type
class FeaturesCapabilities(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "importRules":
            suggest = "import_rules"
        elif key == "importSettings":
            suggest = "import_settings"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilities. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilities.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilities.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 create: Optional['outputs.FeaturesCapabilitiesCreate'] = None,
                 import_rules: Optional['outputs.FeaturesCapabilitiesImportRules'] = None,
                 import_settings: Optional['outputs.FeaturesCapabilitiesImportSettings'] = None,
                 update: Optional['outputs.FeaturesCapabilitiesUpdate'] = None):
        """
        :param 'FeaturesCapabilitiesCreateArgs' create: (Optional) Block for create lifecycle settings:
        :param 'FeaturesCapabilitiesImportRulesArgs' import_rules: (Optional) Block for import rules configuration:
        :param 'FeaturesCapabilitiesImportSettingsArgs' import_settings: (Optional) Block for import settings configuration:
        :param 'FeaturesCapabilitiesUpdateArgs' update: (Optional) Block for update settings:
        """
        if create is not None:
            pulumi.set(__self__, "create", create)
        if import_rules is not None:
            pulumi.set(__self__, "import_rules", import_rules)
        if import_settings is not None:
            pulumi.set(__self__, "import_settings", import_settings)
        if update is not None:
            pulumi.set(__self__, "update", update)

    @_builtins.property
    @pulumi.getter
    def create(self) -> Optional['outputs.FeaturesCapabilitiesCreate']:
        """
        (Optional) Block for create lifecycle settings:
        """
        return pulumi.get(self, "create")

    @_builtins.property
    @pulumi.getter(name="importRules")
    def import_rules(self) -> Optional['outputs.FeaturesCapabilitiesImportRules']:
        """
        (Optional) Block for import rules configuration:
        """
        return pulumi.get(self, "import_rules")

    @_builtins.property
    @pulumi.getter(name="importSettings")
    def import_settings(self) -> Optional['outputs.FeaturesCapabilitiesImportSettings']:
        """
        (Optional) Block for import settings configuration:
        """
        return pulumi.get(self, "import_settings")

    @_builtins.property
    @pulumi.getter
    def update(self) -> Optional['outputs.FeaturesCapabilitiesUpdate']:
        """
        (Optional) Block for update settings:
        """
        return pulumi.get(self, "update")


@pulumi.output_type
class FeaturesCapabilitiesCreate(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifecycleCreate":
            suggest = "lifecycle_create"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesCreate. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesCreate.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesCreate.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 lifecycle_create: Optional['outputs.FeaturesCapabilitiesCreateLifecycleCreate'] = None):
        """
        :param 'FeaturesCapabilitiesCreateLifecycleCreateArgs' lifecycle_create: (Optional) Block for create lifecycle configuration:
        """
        if lifecycle_create is not None:
            pulumi.set(__self__, "lifecycle_create", lifecycle_create)

    @_builtins.property
    @pulumi.getter(name="lifecycleCreate")
    def lifecycle_create(self) -> Optional['outputs.FeaturesCapabilitiesCreateLifecycleCreate']:
        """
        (Optional) Block for create lifecycle configuration:
        """
        return pulumi.get(self, "lifecycle_create")


@pulumi.output_type
class FeaturesCapabilitiesCreateLifecycleCreate(dict):
    def __init__(__self__, *,
                 status: Optional[_builtins.str] = None):
        """
        :param _builtins.str status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class FeaturesCapabilitiesImportRules(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "userCreateAndMatch":
            suggest = "user_create_and_match"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesImportRules. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesImportRules.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesImportRules.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 user_create_and_match: Optional['outputs.FeaturesCapabilitiesImportRulesUserCreateAndMatch'] = None):
        """
        :param 'FeaturesCapabilitiesImportRulesUserCreateAndMatchArgs' user_create_and_match: (Optional) Block for user matching and creation rules:
        """
        if user_create_and_match is not None:
            pulumi.set(__self__, "user_create_and_match", user_create_and_match)

    @_builtins.property
    @pulumi.getter(name="userCreateAndMatch")
    def user_create_and_match(self) -> Optional['outputs.FeaturesCapabilitiesImportRulesUserCreateAndMatch']:
        """
        (Optional) Block for user matching and creation rules:
        """
        return pulumi.get(self, "user_create_and_match")


@pulumi.output_type
class FeaturesCapabilitiesImportRulesUserCreateAndMatch(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowPartialMatch":
            suggest = "allow_partial_match"
        elif key == "autoActivateNewUsers":
            suggest = "auto_activate_new_users"
        elif key == "autoconfirmExactMatch":
            suggest = "autoconfirm_exact_match"
        elif key == "autoconfirmNewUsers":
            suggest = "autoconfirm_new_users"
        elif key == "autoconfirmPartialMatch":
            suggest = "autoconfirm_partial_match"
        elif key == "exactMatchCriteria":
            suggest = "exact_match_criteria"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesImportRulesUserCreateAndMatch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesImportRulesUserCreateAndMatch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesImportRulesUserCreateAndMatch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_partial_match: Optional[_builtins.bool] = None,
                 auto_activate_new_users: Optional[_builtins.bool] = None,
                 autoconfirm_exact_match: Optional[_builtins.bool] = None,
                 autoconfirm_new_users: Optional[_builtins.bool] = None,
                 autoconfirm_partial_match: Optional[_builtins.bool] = None,
                 exact_match_criteria: Optional[_builtins.str] = None):
        """
        :param _builtins.bool allow_partial_match: (Optional) Whether to allow partial matching based on first and last names.
        :param _builtins.bool auto_activate_new_users: (Optional) Whether imported new users are automatically activated.
        :param _builtins.bool autoconfirm_exact_match: (Optional) Whether exact-matched users are automatically confirmed.
        :param _builtins.bool autoconfirm_new_users: (Optional) Whether imported new users are automatically confirmed.
        :param _builtins.bool autoconfirm_partial_match: (Optional) Whether partially matched users are automatically confirmed.
        :param _builtins.str exact_match_criteria: (Optional) Attribute used for exact matching (e.g., `USERNAME`, `EMAIL`).
        """
        if allow_partial_match is not None:
            pulumi.set(__self__, "allow_partial_match", allow_partial_match)
        if auto_activate_new_users is not None:
            pulumi.set(__self__, "auto_activate_new_users", auto_activate_new_users)
        if autoconfirm_exact_match is not None:
            pulumi.set(__self__, "autoconfirm_exact_match", autoconfirm_exact_match)
        if autoconfirm_new_users is not None:
            pulumi.set(__self__, "autoconfirm_new_users", autoconfirm_new_users)
        if autoconfirm_partial_match is not None:
            pulumi.set(__self__, "autoconfirm_partial_match", autoconfirm_partial_match)
        if exact_match_criteria is not None:
            pulumi.set(__self__, "exact_match_criteria", exact_match_criteria)

    @_builtins.property
    @pulumi.getter(name="allowPartialMatch")
    def allow_partial_match(self) -> Optional[_builtins.bool]:
        """
        (Optional) Whether to allow partial matching based on first and last names.
        """
        return pulumi.get(self, "allow_partial_match")

    @_builtins.property
    @pulumi.getter(name="autoActivateNewUsers")
    def auto_activate_new_users(self) -> Optional[_builtins.bool]:
        """
        (Optional) Whether imported new users are automatically activated.
        """
        return pulumi.get(self, "auto_activate_new_users")

    @_builtins.property
    @pulumi.getter(name="autoconfirmExactMatch")
    def autoconfirm_exact_match(self) -> Optional[_builtins.bool]:
        """
        (Optional) Whether exact-matched users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_exact_match")

    @_builtins.property
    @pulumi.getter(name="autoconfirmNewUsers")
    def autoconfirm_new_users(self) -> Optional[_builtins.bool]:
        """
        (Optional) Whether imported new users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_new_users")

    @_builtins.property
    @pulumi.getter(name="autoconfirmPartialMatch")
    def autoconfirm_partial_match(self) -> Optional[_builtins.bool]:
        """
        (Optional) Whether partially matched users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_partial_match")

    @_builtins.property
    @pulumi.getter(name="exactMatchCriteria")
    def exact_match_criteria(self) -> Optional[_builtins.str]:
        """
        (Optional) Attribute used for exact matching (e.g., `USERNAME`, `EMAIL`).
        """
        return pulumi.get(self, "exact_match_criteria")


@pulumi.output_type
class FeaturesCapabilitiesImportSettings(dict):
    def __init__(__self__, *,
                 schedule: Optional['outputs.FeaturesCapabilitiesImportSettingsSchedule'] = None,
                 username: Optional['outputs.FeaturesCapabilitiesImportSettingsUsername'] = None):
        """
        :param 'FeaturesCapabilitiesImportSettingsScheduleArgs' schedule: (Optional) Block for import schedule configuration:
        :param 'FeaturesCapabilitiesImportSettingsUsernameArgs' username: (Optional) Block for username configuration:
        """
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.FeaturesCapabilitiesImportSettingsSchedule']:
        """
        (Optional) Block for import schedule configuration:
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional['outputs.FeaturesCapabilitiesImportSettingsUsername']:
        """
        (Optional) Block for username configuration:
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class FeaturesCapabilitiesImportSettingsSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "fullImport":
            suggest = "full_import"
        elif key == "incrementalImport":
            suggest = "incremental_import"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesImportSettingsSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesImportSettingsSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesImportSettingsSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 full_import: Optional['outputs.FeaturesCapabilitiesImportSettingsScheduleFullImport'] = None,
                 incremental_import: Optional['outputs.FeaturesCapabilitiesImportSettingsScheduleIncrementalImport'] = None,
                 status: Optional[_builtins.str] = None):
        """
        :param 'FeaturesCapabilitiesImportSettingsScheduleFullImportArgs' full_import: (Optional) Block for full import schedule:
        :param 'FeaturesCapabilitiesImportSettingsScheduleIncrementalImportArgs' incremental_import: (Optional) Block for incremental import schedule:
        :param _builtins.str status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if full_import is not None:
            pulumi.set(__self__, "full_import", full_import)
        if incremental_import is not None:
            pulumi.set(__self__, "incremental_import", incremental_import)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="fullImport")
    def full_import(self) -> Optional['outputs.FeaturesCapabilitiesImportSettingsScheduleFullImport']:
        """
        (Optional) Block for full import schedule:
        """
        return pulumi.get(self, "full_import")

    @_builtins.property
    @pulumi.getter(name="incrementalImport")
    def incremental_import(self) -> Optional['outputs.FeaturesCapabilitiesImportSettingsScheduleIncrementalImport']:
        """
        (Optional) Block for incremental import schedule:
        """
        return pulumi.get(self, "incremental_import")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class FeaturesCapabilitiesImportSettingsScheduleFullImport(dict):
    def __init__(__self__, *,
                 expression: Optional[_builtins.str] = None,
                 timezone: Optional[_builtins.str] = None):
        """
        :param _builtins.str expression: (Optional) UNIX cron expression for incremental import schedule.
        :param _builtins.str timezone: (Optional) IANA timezone name for the schedule.
        """
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[_builtins.str]:
        """
        (Optional) UNIX cron expression for incremental import schedule.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> Optional[_builtins.str]:
        """
        (Optional) IANA timezone name for the schedule.
        """
        return pulumi.get(self, "timezone")


@pulumi.output_type
class FeaturesCapabilitiesImportSettingsScheduleIncrementalImport(dict):
    def __init__(__self__, *,
                 expression: Optional[_builtins.str] = None,
                 timezone: Optional[_builtins.str] = None):
        """
        :param _builtins.str expression: (Optional) UNIX cron expression for incremental import schedule.
        :param _builtins.str timezone: (Optional) IANA timezone name for the schedule.
        """
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if timezone is not None:
            pulumi.set(__self__, "timezone", timezone)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[_builtins.str]:
        """
        (Optional) UNIX cron expression for incremental import schedule.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> Optional[_builtins.str]:
        """
        (Optional) IANA timezone name for the schedule.
        """
        return pulumi.get(self, "timezone")


@pulumi.output_type
class FeaturesCapabilitiesImportSettingsUsername(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "usernameExpression":
            suggest = "username_expression"
        elif key == "usernameFormat":
            suggest = "username_format"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesImportSettingsUsername. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesImportSettingsUsername.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesImportSettingsUsername.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 username_expression: Optional[_builtins.str] = None,
                 username_format: Optional[_builtins.str] = None):
        """
        :param _builtins.str username_expression: (Optional) Okta Expression Language statement for custom username format.
        :param _builtins.str username_format: (Optional) Format for usernames (e.g., `EMAIL`, `CUSTOM`).
        """
        if username_expression is not None:
            pulumi.set(__self__, "username_expression", username_expression)
        if username_format is not None:
            pulumi.set(__self__, "username_format", username_format)

    @_builtins.property
    @pulumi.getter(name="usernameExpression")
    def username_expression(self) -> Optional[_builtins.str]:
        """
        (Optional) Okta Expression Language statement for custom username format.
        """
        return pulumi.get(self, "username_expression")

    @_builtins.property
    @pulumi.getter(name="usernameFormat")
    def username_format(self) -> Optional[_builtins.str]:
        """
        (Optional) Format for usernames (e.g., `EMAIL`, `CUSTOM`).
        """
        return pulumi.get(self, "username_format")


@pulumi.output_type
class FeaturesCapabilitiesUpdate(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lifecycleDeactivate":
            suggest = "lifecycle_deactivate"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in FeaturesCapabilitiesUpdate. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        FeaturesCapabilitiesUpdate.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        FeaturesCapabilitiesUpdate.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 lifecycle_deactivate: Optional['outputs.FeaturesCapabilitiesUpdateLifecycleDeactivate'] = None,
                 password: Optional['outputs.FeaturesCapabilitiesUpdatePassword'] = None,
                 profile: Optional['outputs.FeaturesCapabilitiesUpdateProfile'] = None):
        """
        :param 'FeaturesCapabilitiesUpdateLifecycleDeactivateArgs' lifecycle_deactivate: (Optional) Block for deactivation lifecycle configuration:
        :param 'FeaturesCapabilitiesUpdatePasswordArgs' password: (Optional) Block for password synchronization settings:
        :param 'FeaturesCapabilitiesUpdateProfileArgs' profile: (Optional) Block for profile update settings:
        """
        if lifecycle_deactivate is not None:
            pulumi.set(__self__, "lifecycle_deactivate", lifecycle_deactivate)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)

    @_builtins.property
    @pulumi.getter(name="lifecycleDeactivate")
    def lifecycle_deactivate(self) -> Optional['outputs.FeaturesCapabilitiesUpdateLifecycleDeactivate']:
        """
        (Optional) Block for deactivation lifecycle configuration:
        """
        return pulumi.get(self, "lifecycle_deactivate")

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional['outputs.FeaturesCapabilitiesUpdatePassword']:
        """
        (Optional) Block for password synchronization settings:
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional['outputs.FeaturesCapabilitiesUpdateProfile']:
        """
        (Optional) Block for profile update settings:
        """
        return pulumi.get(self, "profile")


@pulumi.output_type
class FeaturesCapabilitiesUpdateLifecycleDeactivate(dict):
    def __init__(__self__, *,
                 status: Optional[_builtins.str] = None):
        """
        :param _builtins.str status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class FeaturesCapabilitiesUpdatePassword(dict):
    def __init__(__self__, *,
                 change: Optional[_builtins.str] = None,
                 seed: Optional[_builtins.str] = None,
                 status: Optional[_builtins.str] = None):
        """
        :param _builtins.str change: (Optional) Determines password change behavior. Valid values are `CHANGE` or `KEEP_EXISTING`.
        :param _builtins.str seed: (Optional) Determines password source. Valid values are `OKTA` or `RANDOM`.
        :param _builtins.str status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if change is not None:
            pulumi.set(__self__, "change", change)
        if seed is not None:
            pulumi.set(__self__, "seed", seed)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def change(self) -> Optional[_builtins.str]:
        """
        (Optional) Determines password change behavior. Valid values are `CHANGE` or `KEEP_EXISTING`.
        """
        return pulumi.get(self, "change")

    @_builtins.property
    @pulumi.getter
    def seed(self) -> Optional[_builtins.str]:
        """
        (Optional) Determines password source. Valid values are `OKTA` or `RANDOM`.
        """
        return pulumi.get(self, "seed")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class FeaturesCapabilitiesUpdateProfile(dict):
    def __init__(__self__, *,
                 status: Optional[_builtins.str] = None):
        """
        :param _builtins.str status: The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the feature. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class OAuthGroupsClaim(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "filterType":
            suggest = "filter_type"
        elif key == "issuerMode":
            suggest = "issuer_mode"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OAuthGroupsClaim. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OAuthGroupsClaim.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OAuthGroupsClaim.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 type: _builtins.str,
                 value: _builtins.str,
                 filter_type: Optional[_builtins.str] = None,
                 issuer_mode: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: Name of the claim that will be used in the token.
        :param _builtins.str type: Groups claim type.
        :param _builtins.str value: Value of the claim. Can be an Okta Expression Language statement that evaluates at the time the token is minted.
        :param _builtins.str filter_type: Groups claim filter. Can only be set if type is FILTER.
        :param _builtins.str issuer_mode: Issuer mode inherited from OAuth App
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)
        if filter_type is not None:
            pulumi.set(__self__, "filter_type", filter_type)
        if issuer_mode is not None:
            pulumi.set(__self__, "issuer_mode", issuer_mode)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the claim that will be used in the token.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Groups claim type.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        Value of the claim. Can be an Okta Expression Language statement that evaluates at the time the token is minted.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="filterType")
    def filter_type(self) -> Optional[_builtins.str]:
        """
        Groups claim filter. Can only be set if type is FILTER.
        """
        return pulumi.get(self, "filter_type")

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> Optional[_builtins.str]:
        """
        Issuer mode inherited from OAuth App
        """
        return pulumi.get(self, "issuer_mode")


@pulumi.output_type
class OAuthJwk(dict):
    def __init__(__self__, *,
                 kid: _builtins.str,
                 kty: _builtins.str,
                 e: Optional[_builtins.str] = None,
                 n: Optional[_builtins.str] = None,
                 x: Optional[_builtins.str] = None,
                 y: Optional[_builtins.str] = None):
        """
        :param _builtins.str kid: Key ID
        :param _builtins.str kty: Key type
        :param _builtins.str e: RSA Exponent
        :param _builtins.str n: RSA Modulus
        :param _builtins.str x: X coordinate of the elliptic curve point
        :param _builtins.str y: Y coordinate of the elliptic curve point
        """
        pulumi.set(__self__, "kid", kid)
        pulumi.set(__self__, "kty", kty)
        if e is not None:
            pulumi.set(__self__, "e", e)
        if n is not None:
            pulumi.set(__self__, "n", n)
        if x is not None:
            pulumi.set(__self__, "x", x)
        if y is not None:
            pulumi.set(__self__, "y", y)

    @_builtins.property
    @pulumi.getter
    def kid(self) -> _builtins.str:
        """
        Key ID
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def kty(self) -> _builtins.str:
        """
        Key type
        """
        return pulumi.get(self, "kty")

    @_builtins.property
    @pulumi.getter
    def e(self) -> Optional[_builtins.str]:
        """
        RSA Exponent
        """
        return pulumi.get(self, "e")

    @_builtins.property
    @pulumi.getter
    def n(self) -> Optional[_builtins.str]:
        """
        RSA Modulus
        """
        return pulumi.get(self, "n")

    @_builtins.property
    @pulumi.getter
    def x(self) -> Optional[_builtins.str]:
        """
        X coordinate of the elliptic curve point
        """
        return pulumi.get(self, "x")

    @_builtins.property
    @pulumi.getter
    def y(self) -> Optional[_builtins.str]:
        """
        Y coordinate of the elliptic curve point
        """
        return pulumi.get(self, "y")


@pulumi.output_type
class SamlAcsEndpointsIndex(dict):
    def __init__(__self__, *,
                 index: _builtins.int,
                 url: _builtins.str):
        pulumi.set(__self__, "index", index)
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def index(self) -> _builtins.int:
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        return pulumi.get(self, "url")


@pulumi.output_type
class SamlAttributeStatement(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "filterType":
            suggest = "filter_type"
        elif key == "filterValue":
            suggest = "filter_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SamlAttributeStatement. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SamlAttributeStatement.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SamlAttributeStatement.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: _builtins.str,
                 filter_type: Optional[_builtins.str] = None,
                 filter_value: Optional[_builtins.str] = None,
                 namespace: Optional[_builtins.str] = None,
                 type: Optional[_builtins.str] = None,
                 values: Optional[Sequence[_builtins.str]] = None):
        """
        :param _builtins.str name: The reference name of the attribute statement
        :param _builtins.str filter_type: Type of group attribute filter. Valid values are: `STARTS_WITH`, `EQUALS`, `CONTAINS`, or `REGEX`
        :param _builtins.str filter_value: Filter value to use
        :param _builtins.str namespace: The attribute namespace. It can be set to `urn:oasis:names:tc:SAML:2.0:attrname-format:unspecified`, `urn:oasis:names:tc:SAML:2.0:attrname-format:uri`, or `urn:oasis:names:tc:SAML:2.0:attrname-format:basic`
        :param _builtins.str type: The type of attribute statements object
        """
        pulumi.set(__self__, "name", name)
        if filter_type is not None:
            pulumi.set(__self__, "filter_type", filter_type)
        if filter_value is not None:
            pulumi.set(__self__, "filter_value", filter_value)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The reference name of the attribute statement
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="filterType")
    def filter_type(self) -> Optional[_builtins.str]:
        """
        Type of group attribute filter. Valid values are: `STARTS_WITH`, `EQUALS`, `CONTAINS`, or `REGEX`
        """
        return pulumi.get(self, "filter_type")

    @_builtins.property
    @pulumi.getter(name="filterValue")
    def filter_value(self) -> Optional[_builtins.str]:
        """
        Filter value to use
        """
        return pulumi.get(self, "filter_value")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        """
        The attribute namespace. It can be set to `urn:oasis:names:tc:SAML:2.0:attrname-format:unspecified`, `urn:oasis:names:tc:SAML:2.0:attrname-format:uri`, or `urn:oasis:names:tc:SAML:2.0:attrname-format:basic`
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        The type of attribute statements object
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "values")


@pulumi.output_type
class SamlKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expiresAt":
            suggest = "expires_at"
        elif key == "lastUpdated":
            suggest = "last_updated"
        elif key == "x5tS256":
            suggest = "x5t_s256"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SamlKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SamlKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SamlKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 created: Optional[_builtins.str] = None,
                 e: Optional[_builtins.str] = None,
                 expires_at: Optional[_builtins.str] = None,
                 kid: Optional[_builtins.str] = None,
                 kty: Optional[_builtins.str] = None,
                 last_updated: Optional[_builtins.str] = None,
                 n: Optional[_builtins.str] = None,
                 use: Optional[_builtins.str] = None,
                 x5cs: Optional[Sequence[_builtins.str]] = None,
                 x5t_s256: Optional[_builtins.str] = None):
        """
        :param _builtins.str created: Created date
        :param _builtins.str e: RSA exponent
        :param _builtins.str expires_at: Expiration date
        :param _builtins.str kid: Key ID
        :param _builtins.str kty: Key type. Identifies the cryptographic algorithm family used with the key.
        :param _builtins.str last_updated: Last updated date
        :param _builtins.str n: RSA modulus
        :param _builtins.str use: Intended use of the public key.
        :param Sequence[_builtins.str] x5cs: X.509 Certificate Chain
        :param _builtins.str x5t_s256: X.509 certificate SHA-256 thumbprint
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if e is not None:
            pulumi.set(__self__, "e", e)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if kid is not None:
            pulumi.set(__self__, "kid", kid)
        if kty is not None:
            pulumi.set(__self__, "kty", kty)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if n is not None:
            pulumi.set(__self__, "n", n)
        if use is not None:
            pulumi.set(__self__, "use", use)
        if x5cs is not None:
            pulumi.set(__self__, "x5cs", x5cs)
        if x5t_s256 is not None:
            pulumi.set(__self__, "x5t_s256", x5t_s256)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[_builtins.str]:
        """
        Created date
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def e(self) -> Optional[_builtins.str]:
        """
        RSA exponent
        """
        return pulumi.get(self, "e")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[_builtins.str]:
        """
        Expiration date
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> Optional[_builtins.str]:
        """
        Key ID
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def kty(self) -> Optional[_builtins.str]:
        """
        Key type. Identifies the cryptographic algorithm family used with the key.
        """
        return pulumi.get(self, "kty")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[_builtins.str]:
        """
        Last updated date
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def n(self) -> Optional[_builtins.str]:
        """
        RSA modulus
        """
        return pulumi.get(self, "n")

    @_builtins.property
    @pulumi.getter
    def use(self) -> Optional[_builtins.str]:
        """
        Intended use of the public key.
        """
        return pulumi.get(self, "use")

    @_builtins.property
    @pulumi.getter
    def x5cs(self) -> Optional[Sequence[_builtins.str]]:
        """
        X.509 Certificate Chain
        """
        return pulumi.get(self, "x5cs")

    @_builtins.property
    @pulumi.getter(name="x5tS256")
    def x5t_s256(self) -> Optional[_builtins.str]:
        """
        X.509 certificate SHA-256 thumbprint
        """
        return pulumi.get(self, "x5t_s256")


@pulumi.output_type
class GetConnectionProfileResult(dict):
    def __init__(__self__, *,
                 auth_scheme: _builtins.str):
        """
        :param _builtins.str auth_scheme: Defines the method of authentication.
        """
        pulumi.set(__self__, "auth_scheme", auth_scheme)

    @_builtins.property
    @pulumi.getter(name="authScheme")
    def auth_scheme(self) -> _builtins.str:
        """
        Defines the method of authentication.
        """
        return pulumi.get(self, "auth_scheme")


@pulumi.output_type
class GetFeaturesCapabilitiesResult(dict):
    def __init__(__self__, *,
                 create: Optional['outputs.GetFeaturesCapabilitiesCreateResult'] = None,
                 import_rules: Optional['outputs.GetFeaturesCapabilitiesImportRulesResult'] = None,
                 import_settings: Optional['outputs.GetFeaturesCapabilitiesImportSettingsResult'] = None,
                 update: Optional['outputs.GetFeaturesCapabilitiesUpdateResult'] = None):
        """
        :param 'GetFeaturesCapabilitiesCreateArgs' create: Block for create lifecycle settings:
        :param 'GetFeaturesCapabilitiesImportRulesArgs' import_rules: Block for import rules configuration:
        :param 'GetFeaturesCapabilitiesImportSettingsArgs' import_settings: Block for import settings configuration:
        :param 'GetFeaturesCapabilitiesUpdateArgs' update: Block for update settings:
        """
        if create is not None:
            pulumi.set(__self__, "create", create)
        if import_rules is not None:
            pulumi.set(__self__, "import_rules", import_rules)
        if import_settings is not None:
            pulumi.set(__self__, "import_settings", import_settings)
        if update is not None:
            pulumi.set(__self__, "update", update)

    @_builtins.property
    @pulumi.getter
    def create(self) -> Optional['outputs.GetFeaturesCapabilitiesCreateResult']:
        """
        Block for create lifecycle settings:
        """
        return pulumi.get(self, "create")

    @_builtins.property
    @pulumi.getter(name="importRules")
    def import_rules(self) -> Optional['outputs.GetFeaturesCapabilitiesImportRulesResult']:
        """
        Block for import rules configuration:
        """
        return pulumi.get(self, "import_rules")

    @_builtins.property
    @pulumi.getter(name="importSettings")
    def import_settings(self) -> Optional['outputs.GetFeaturesCapabilitiesImportSettingsResult']:
        """
        Block for import settings configuration:
        """
        return pulumi.get(self, "import_settings")

    @_builtins.property
    @pulumi.getter
    def update(self) -> Optional['outputs.GetFeaturesCapabilitiesUpdateResult']:
        """
        Block for update settings:
        """
        return pulumi.get(self, "update")


@pulumi.output_type
class GetFeaturesCapabilitiesCreateResult(dict):
    def __init__(__self__, *,
                 lifecycle_create: Optional['outputs.GetFeaturesCapabilitiesCreateLifecycleCreateResult'] = None):
        """
        :param 'GetFeaturesCapabilitiesCreateLifecycleCreateArgs' lifecycle_create: Block for create lifecycle configuration:
        """
        if lifecycle_create is not None:
            pulumi.set(__self__, "lifecycle_create", lifecycle_create)

    @_builtins.property
    @pulumi.getter(name="lifecycleCreate")
    def lifecycle_create(self) -> Optional['outputs.GetFeaturesCapabilitiesCreateLifecycleCreateResult']:
        """
        Block for create lifecycle configuration:
        """
        return pulumi.get(self, "lifecycle_create")


@pulumi.output_type
class GetFeaturesCapabilitiesCreateLifecycleCreateResult(dict):
    def __init__(__self__, *,
                 status: _builtins.str):
        """
        :param _builtins.str status: (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetFeaturesCapabilitiesImportRulesResult(dict):
    def __init__(__self__, *,
                 user_create_and_match: Optional['outputs.GetFeaturesCapabilitiesImportRulesUserCreateAndMatchResult'] = None):
        """
        :param 'GetFeaturesCapabilitiesImportRulesUserCreateAndMatchArgs' user_create_and_match: Block for user matching and creation rules:
        """
        if user_create_and_match is not None:
            pulumi.set(__self__, "user_create_and_match", user_create_and_match)

    @_builtins.property
    @pulumi.getter(name="userCreateAndMatch")
    def user_create_and_match(self) -> Optional['outputs.GetFeaturesCapabilitiesImportRulesUserCreateAndMatchResult']:
        """
        Block for user matching and creation rules:
        """
        return pulumi.get(self, "user_create_and_match")


@pulumi.output_type
class GetFeaturesCapabilitiesImportRulesUserCreateAndMatchResult(dict):
    def __init__(__self__, *,
                 allow_partial_match: _builtins.bool,
                 auto_activate_new_users: _builtins.bool,
                 autoconfirm_exact_match: _builtins.bool,
                 autoconfirm_new_users: _builtins.bool,
                 autoconfirm_partial_match: _builtins.bool,
                 exact_match_criteria: _builtins.str):
        """
        :param _builtins.bool allow_partial_match: (Boolean) Whether to allow partial matching based on first and last names.
        :param _builtins.bool auto_activate_new_users: (Boolean) Whether imported new users are automatically activated.
        :param _builtins.bool autoconfirm_exact_match: (Boolean) Whether exact-matched users are automatically confirmed.
        :param _builtins.bool autoconfirm_new_users: (Boolean) Whether imported new users are automatically confirmed.
        :param _builtins.bool autoconfirm_partial_match: (Boolean) Whether partially matched users are automatically confirmed.
        :param _builtins.str exact_match_criteria: (String) Attribute used for exact matching (e.g., `USERNAME`, `EMAIL`).
        """
        pulumi.set(__self__, "allow_partial_match", allow_partial_match)
        pulumi.set(__self__, "auto_activate_new_users", auto_activate_new_users)
        pulumi.set(__self__, "autoconfirm_exact_match", autoconfirm_exact_match)
        pulumi.set(__self__, "autoconfirm_new_users", autoconfirm_new_users)
        pulumi.set(__self__, "autoconfirm_partial_match", autoconfirm_partial_match)
        pulumi.set(__self__, "exact_match_criteria", exact_match_criteria)

    @_builtins.property
    @pulumi.getter(name="allowPartialMatch")
    def allow_partial_match(self) -> _builtins.bool:
        """
        (Boolean) Whether to allow partial matching based on first and last names.
        """
        return pulumi.get(self, "allow_partial_match")

    @_builtins.property
    @pulumi.getter(name="autoActivateNewUsers")
    def auto_activate_new_users(self) -> _builtins.bool:
        """
        (Boolean) Whether imported new users are automatically activated.
        """
        return pulumi.get(self, "auto_activate_new_users")

    @_builtins.property
    @pulumi.getter(name="autoconfirmExactMatch")
    def autoconfirm_exact_match(self) -> _builtins.bool:
        """
        (Boolean) Whether exact-matched users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_exact_match")

    @_builtins.property
    @pulumi.getter(name="autoconfirmNewUsers")
    def autoconfirm_new_users(self) -> _builtins.bool:
        """
        (Boolean) Whether imported new users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_new_users")

    @_builtins.property
    @pulumi.getter(name="autoconfirmPartialMatch")
    def autoconfirm_partial_match(self) -> _builtins.bool:
        """
        (Boolean) Whether partially matched users are automatically confirmed.
        """
        return pulumi.get(self, "autoconfirm_partial_match")

    @_builtins.property
    @pulumi.getter(name="exactMatchCriteria")
    def exact_match_criteria(self) -> _builtins.str:
        """
        (String) Attribute used for exact matching (e.g., `USERNAME`, `EMAIL`).
        """
        return pulumi.get(self, "exact_match_criteria")


@pulumi.output_type
class GetFeaturesCapabilitiesImportSettingsResult(dict):
    def __init__(__self__, *,
                 schedule: Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleResult'] = None,
                 username: Optional['outputs.GetFeaturesCapabilitiesImportSettingsUsernameResult'] = None):
        """
        :param 'GetFeaturesCapabilitiesImportSettingsScheduleArgs' schedule: Block for import schedule configuration:
        :param 'GetFeaturesCapabilitiesImportSettingsUsernameArgs' username: Block for username configuration:
        """
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleResult']:
        """
        Block for import schedule configuration:
        """
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional['outputs.GetFeaturesCapabilitiesImportSettingsUsernameResult']:
        """
        Block for username configuration:
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetFeaturesCapabilitiesImportSettingsScheduleResult(dict):
    def __init__(__self__, *,
                 status: _builtins.str,
                 full_import: Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleFullImportResult'] = None,
                 incremental_import: Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleIncrementalImportResult'] = None):
        """
        :param _builtins.str status: (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        :param 'GetFeaturesCapabilitiesImportSettingsScheduleFullImportArgs' full_import: Block for full import schedule:
        :param 'GetFeaturesCapabilitiesImportSettingsScheduleIncrementalImportArgs' incremental_import: Block for incremental import schedule:
        """
        pulumi.set(__self__, "status", status)
        if full_import is not None:
            pulumi.set(__self__, "full_import", full_import)
        if incremental_import is not None:
            pulumi.set(__self__, "incremental_import", incremental_import)

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="fullImport")
    def full_import(self) -> Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleFullImportResult']:
        """
        Block for full import schedule:
        """
        return pulumi.get(self, "full_import")

    @_builtins.property
    @pulumi.getter(name="incrementalImport")
    def incremental_import(self) -> Optional['outputs.GetFeaturesCapabilitiesImportSettingsScheduleIncrementalImportResult']:
        """
        Block for incremental import schedule:
        """
        return pulumi.get(self, "incremental_import")


@pulumi.output_type
class GetFeaturesCapabilitiesImportSettingsScheduleFullImportResult(dict):
    def __init__(__self__, *,
                 expression: _builtins.str,
                 timezone: _builtins.str):
        """
        :param _builtins.str expression: (String) UNIX cron expression for incremental import schedule.
        :param _builtins.str timezone: (String) IANA timezone name for the schedule.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "timezone", timezone)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> _builtins.str:
        """
        (String) UNIX cron expression for incremental import schedule.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> _builtins.str:
        """
        (String) IANA timezone name for the schedule.
        """
        return pulumi.get(self, "timezone")


@pulumi.output_type
class GetFeaturesCapabilitiesImportSettingsScheduleIncrementalImportResult(dict):
    def __init__(__self__, *,
                 expression: _builtins.str,
                 timezone: _builtins.str):
        """
        :param _builtins.str expression: (String) UNIX cron expression for incremental import schedule.
        :param _builtins.str timezone: (String) IANA timezone name for the schedule.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "timezone", timezone)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> _builtins.str:
        """
        (String) UNIX cron expression for incremental import schedule.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def timezone(self) -> _builtins.str:
        """
        (String) IANA timezone name for the schedule.
        """
        return pulumi.get(self, "timezone")


@pulumi.output_type
class GetFeaturesCapabilitiesImportSettingsUsernameResult(dict):
    def __init__(__self__, *,
                 username_expression: _builtins.str,
                 username_format: _builtins.str):
        """
        :param _builtins.str username_expression: (String) Okta Expression Language statement for custom username format.
        :param _builtins.str username_format: (String) Format for usernames (e.g., `EMAIL`, `CUSTOM`).
        """
        pulumi.set(__self__, "username_expression", username_expression)
        pulumi.set(__self__, "username_format", username_format)

    @_builtins.property
    @pulumi.getter(name="usernameExpression")
    def username_expression(self) -> _builtins.str:
        """
        (String) Okta Expression Language statement for custom username format.
        """
        return pulumi.get(self, "username_expression")

    @_builtins.property
    @pulumi.getter(name="usernameFormat")
    def username_format(self) -> _builtins.str:
        """
        (String) Format for usernames (e.g., `EMAIL`, `CUSTOM`).
        """
        return pulumi.get(self, "username_format")


@pulumi.output_type
class GetFeaturesCapabilitiesUpdateResult(dict):
    def __init__(__self__, *,
                 lifecycle_deactivate: Optional['outputs.GetFeaturesCapabilitiesUpdateLifecycleDeactivateResult'] = None,
                 password: Optional['outputs.GetFeaturesCapabilitiesUpdatePasswordResult'] = None,
                 profile: Optional['outputs.GetFeaturesCapabilitiesUpdateProfileResult'] = None):
        """
        :param 'GetFeaturesCapabilitiesUpdateLifecycleDeactivateArgs' lifecycle_deactivate: Block for deactivation lifecycle configuration:
        :param 'GetFeaturesCapabilitiesUpdatePasswordArgs' password: Block for password synchronization settings:
        :param 'GetFeaturesCapabilitiesUpdateProfileArgs' profile: Block for profile update settings:
        """
        if lifecycle_deactivate is not None:
            pulumi.set(__self__, "lifecycle_deactivate", lifecycle_deactivate)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)

    @_builtins.property
    @pulumi.getter(name="lifecycleDeactivate")
    def lifecycle_deactivate(self) -> Optional['outputs.GetFeaturesCapabilitiesUpdateLifecycleDeactivateResult']:
        """
        Block for deactivation lifecycle configuration:
        """
        return pulumi.get(self, "lifecycle_deactivate")

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional['outputs.GetFeaturesCapabilitiesUpdatePasswordResult']:
        """
        Block for password synchronization settings:
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional['outputs.GetFeaturesCapabilitiesUpdateProfileResult']:
        """
        Block for profile update settings:
        """
        return pulumi.get(self, "profile")


@pulumi.output_type
class GetFeaturesCapabilitiesUpdateLifecycleDeactivateResult(dict):
    def __init__(__self__, *,
                 status: _builtins.str):
        """
        :param _builtins.str status: (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetFeaturesCapabilitiesUpdatePasswordResult(dict):
    def __init__(__self__, *,
                 change: _builtins.str,
                 seed: _builtins.str,
                 status: _builtins.str):
        """
        :param _builtins.str change: (String) Determines password change behavior. Valid values are `CHANGE` or `KEEP_EXISTING`.
        :param _builtins.str seed: (String) Determines password source. Valid values are `OKTA` or `RANDOM`.
        :param _builtins.str status: (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        pulumi.set(__self__, "change", change)
        pulumi.set(__self__, "seed", seed)
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def change(self) -> _builtins.str:
        """
        (String) Determines password change behavior. Valid values are `CHANGE` or `KEEP_EXISTING`.
        """
        return pulumi.get(self, "change")

    @_builtins.property
    @pulumi.getter
    def seed(self) -> _builtins.str:
        """
        (String) Determines password source. Valid values are `OKTA` or `RANDOM`.
        """
        return pulumi.get(self, "seed")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetFeaturesCapabilitiesUpdateProfileResult(dict):
    def __init__(__self__, *,
                 status: _builtins.str):
        """
        :param _builtins.str status: (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (String) Status of the import schedule. Valid values are `ENABLED` or `DISABLED`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetSamlAttributeStatementResult(dict):
    def __init__(__self__, *,
                 filter_type: _builtins.str,
                 filter_value: _builtins.str,
                 name: _builtins.str,
                 namespace: _builtins.str,
                 type: _builtins.str,
                 values: Sequence[_builtins.str]):
        """
        :param _builtins.str filter_type: Type of group attribute filter
        :param _builtins.str filter_value: Filter value to use
        :param _builtins.str name: The reference name of the attribute statement
        :param _builtins.str namespace: The name format of the attribute
        :param _builtins.str type: The type of attribute statements object
        """
        pulumi.set(__self__, "filter_type", filter_type)
        pulumi.set(__self__, "filter_value", filter_value)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="filterType")
    def filter_type(self) -> _builtins.str:
        """
        Type of group attribute filter
        """
        return pulumi.get(self, "filter_type")

    @_builtins.property
    @pulumi.getter(name="filterValue")
    def filter_value(self) -> _builtins.str:
        """
        Filter value to use
        """
        return pulumi.get(self, "filter_value")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The reference name of the attribute statement
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        The name format of the attribute
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of attribute statements object
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def values(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "values")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RequestV2Args', 'RequestV2']

@pulumi.input_type
class RequestV2Args:
    def __init__(__self__, *,
                 requested: Optional[pulumi.Input['RequestV2RequestedArgs']] = None,
                 requested_for: Optional[pulumi.Input['RequestV2RequestedForArgs']] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]] = None):
        """
        The set of arguments for constructing a RequestV2 resource.
        :param pulumi.Input['RequestV2RequestedArgs'] requested: A representation of a resource that can be requested for access.
        :param pulumi.Input['RequestV2RequestedForArgs'] requested_for: A representation of a principal.
        :param pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system.
        """
        if requested is not None:
            pulumi.set(__self__, "requested", requested)
        if requested_for is not None:
            pulumi.set(__self__, "requested_for", requested_for)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)

    @_builtins.property
    @pulumi.getter
    def requested(self) -> Optional[pulumi.Input['RequestV2RequestedArgs']]:
        """
        A representation of a resource that can be requested for access.
        """
        return pulumi.get(self, "requested")

    @requested.setter
    def requested(self, value: Optional[pulumi.Input['RequestV2RequestedArgs']]):
        pulumi.set(self, "requested", value)

    @_builtins.property
    @pulumi.getter(name="requestedFor")
    def requested_for(self) -> Optional[pulumi.Input['RequestV2RequestedForArgs']]:
        """
        A representation of a principal.
        """
        return pulumi.get(self, "requested_for")

    @requested_for.setter
    def requested_for(self, value: Optional[pulumi.Input['RequestV2RequestedForArgs']]):
        pulumi.set(self, "requested_for", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)


@pulumi.input_type
class _RequestV2State:
    def __init__(__self__, *,
                 access_duration: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 grant_status: Optional[pulumi.Input[_builtins.str]] = None,
                 granted: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 requested: Optional[pulumi.Input['RequestV2RequestedArgs']] = None,
                 requested_for: Optional[pulumi.Input['RequestV2RequestedForArgs']] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]] = None,
                 resolved: Optional[pulumi.Input[_builtins.str]] = None,
                 revocation_scheduled: Optional[pulumi.Input[_builtins.str]] = None,
                 revocation_status: Optional[pulumi.Input[_builtins.str]] = None,
                 revoked: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RequestV2 resources.
        :param pulumi.Input[_builtins.str] access_duration: How long the requester retains access after their request is approved and fulfilled.
        :param pulumi.Input[_builtins.str] created: The date and time when the request condition was created.
        :param pulumi.Input[_builtins.str] created_by: The id of the user who created the request condition.
        :param pulumi.Input[_builtins.str] grant_status: The status of the granted access request.
        :param pulumi.Input[_builtins.str] granted: The date the approved access was granted. Only set if request . Status is APPROVED.
        :param pulumi.Input[_builtins.str] last_updated: The date and time when the request condition was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of the user who last updated the request condition.
        :param pulumi.Input['RequestV2RequestedArgs'] requested: A representation of a resource that can be requested for access.
        :param pulumi.Input['RequestV2RequestedForArgs'] requested_for: A representation of a principal.
        :param pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]] requester_field_values: The requester input fields required by the approval system.
        :param pulumi.Input[_builtins.str] resolved: The date the request was resolved.
        :param pulumi.Input[_builtins.str] revocation_scheduled: The date the request was scheduled for revocation.
        :param pulumi.Input[_builtins.str] revocation_status: The revocation status of the request.
        :param pulumi.Input[_builtins.str] revoked: The date the granted access was revoked.
        :param pulumi.Input[_builtins.str] status: The status of the request.
        """
        if access_duration is not None:
            pulumi.set(__self__, "access_duration", access_duration)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if grant_status is not None:
            pulumi.set(__self__, "grant_status", grant_status)
        if granted is not None:
            pulumi.set(__self__, "granted", granted)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if requested is not None:
            pulumi.set(__self__, "requested", requested)
        if requested_for is not None:
            pulumi.set(__self__, "requested_for", requested_for)
        if requester_field_values is not None:
            pulumi.set(__self__, "requester_field_values", requester_field_values)
        if resolved is not None:
            pulumi.set(__self__, "resolved", resolved)
        if revocation_scheduled is not None:
            pulumi.set(__self__, "revocation_scheduled", revocation_scheduled)
        if revocation_status is not None:
            pulumi.set(__self__, "revocation_status", revocation_status)
        if revoked is not None:
            pulumi.set(__self__, "revoked", revoked)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="accessDuration")
    def access_duration(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How long the requester retains access after their request is approved and fulfilled.
        """
        return pulumi.get(self, "access_duration")

    @access_duration.setter
    def access_duration(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_duration", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the request condition was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the user who created the request condition.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="grantStatus")
    def grant_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the granted access request.
        """
        return pulumi.get(self, "grant_status")

    @grant_status.setter
    def grant_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "grant_status", value)

    @_builtins.property
    @pulumi.getter
    def granted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date the approved access was granted. Only set if request . Status is APPROVED.
        """
        return pulumi.get(self, "granted")

    @granted.setter
    def granted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "granted", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the request condition was last updated.
        """
        return pulumi.get(self, "last_updated")

    @last_updated.setter
    def last_updated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the user who last updated the request condition.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter
    def requested(self) -> Optional[pulumi.Input['RequestV2RequestedArgs']]:
        """
        A representation of a resource that can be requested for access.
        """
        return pulumi.get(self, "requested")

    @requested.setter
    def requested(self, value: Optional[pulumi.Input['RequestV2RequestedArgs']]):
        pulumi.set(self, "requested", value)

    @_builtins.property
    @pulumi.getter(name="requestedFor")
    def requested_for(self) -> Optional[pulumi.Input['RequestV2RequestedForArgs']]:
        """
        A representation of a principal.
        """
        return pulumi.get(self, "requested_for")

    @requested_for.setter
    def requested_for(self, value: Optional[pulumi.Input['RequestV2RequestedForArgs']]):
        pulumi.set(self, "requested_for", value)

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]]:
        """
        The requester input fields required by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @requester_field_values.setter
    def requester_field_values(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RequestV2RequesterFieldValueArgs']]]]):
        pulumi.set(self, "requester_field_values", value)

    @_builtins.property
    @pulumi.getter
    def resolved(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date the request was resolved.
        """
        return pulumi.get(self, "resolved")

    @resolved.setter
    def resolved(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resolved", value)

    @_builtins.property
    @pulumi.getter(name="revocationScheduled")
    def revocation_scheduled(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date the request was scheduled for revocation.
        """
        return pulumi.get(self, "revocation_scheduled")

    @revocation_scheduled.setter
    def revocation_scheduled(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revocation_scheduled", value)

    @_builtins.property
    @pulumi.getter(name="revocationStatus")
    def revocation_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The revocation status of the request.
        """
        return pulumi.get(self, "revocation_status")

    @revocation_status.setter
    def revocation_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revocation_status", value)

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date the granted access was revoked.
        """
        return pulumi.get(self, "revoked")

    @revoked.setter
    def revoked(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "revoked", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the request.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/requestV2:RequestV2")
class RequestV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 requested: Optional[pulumi.Input[Union['RequestV2RequestedArgs', 'RequestV2RequestedArgsDict']]] = None,
                 requested_for: Optional[pulumi.Input[Union['RequestV2RequestedForArgs', 'RequestV2RequestedForArgsDict']]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RequestV2RequesterFieldValueArgs', 'RequestV2RequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        """
        Manage the access request process. This resource allows you to create and read an Okta [request](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Requests/#tag/Requests).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestV2("test",
            requested={
                "type": "CATALOG_ENTRY",
                "entry_id": "<entry_id>",
            },
            requested_for={
                "type": "OKTA_USER",
                "external_id": "<user_id>",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestV2:RequestV2 example <request_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RequestV2RequestedArgs', 'RequestV2RequestedArgsDict']] requested: A representation of a resource that can be requested for access.
        :param pulumi.Input[Union['RequestV2RequestedForArgs', 'RequestV2RequestedForArgsDict']] requested_for: A representation of a principal.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RequestV2RequesterFieldValueArgs', 'RequestV2RequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RequestV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage the access request process. This resource allows you to create and read an Okta [request](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Requests/#tag/Requests).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.RequestV2("test",
            requested={
                "type": "CATALOG_ENTRY",
                "entry_id": "<entry_id>",
            },
            requested_for={
                "type": "OKTA_USER",
                "external_id": "<user_id>",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestV2:RequestV2 example <request_id>
        ```

        :param str resource_name: The name of the resource.
        :param RequestV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 requested: Optional[pulumi.Input[Union['RequestV2RequestedArgs', 'RequestV2RequestedArgsDict']]] = None,
                 requested_for: Optional[pulumi.Input[Union['RequestV2RequestedForArgs', 'RequestV2RequestedForArgsDict']]] = None,
                 requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RequestV2RequesterFieldValueArgs', 'RequestV2RequesterFieldValueArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestV2Args.__new__(RequestV2Args)

            __props__.__dict__["requested"] = requested
            __props__.__dict__["requested_for"] = requested_for
            __props__.__dict__["requester_field_values"] = requester_field_values
            __props__.__dict__["access_duration"] = None
            __props__.__dict__["created"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["grant_status"] = None
            __props__.__dict__["granted"] = None
            __props__.__dict__["last_updated"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["resolved"] = None
            __props__.__dict__["revocation_scheduled"] = None
            __props__.__dict__["revocation_status"] = None
            __props__.__dict__["revoked"] = None
            __props__.__dict__["status"] = None
        super(RequestV2, __self__).__init__(
            'okta:index/requestV2:RequestV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_duration: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            grant_status: Optional[pulumi.Input[_builtins.str]] = None,
            granted: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            requested: Optional[pulumi.Input[Union['RequestV2RequestedArgs', 'RequestV2RequestedArgsDict']]] = None,
            requested_for: Optional[pulumi.Input[Union['RequestV2RequestedForArgs', 'RequestV2RequestedForArgsDict']]] = None,
            requester_field_values: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RequestV2RequesterFieldValueArgs', 'RequestV2RequesterFieldValueArgsDict']]]]] = None,
            resolved: Optional[pulumi.Input[_builtins.str]] = None,
            revocation_scheduled: Optional[pulumi.Input[_builtins.str]] = None,
            revocation_status: Optional[pulumi.Input[_builtins.str]] = None,
            revoked: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'RequestV2':
        """
        Get an existing RequestV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_duration: How long the requester retains access after their request is approved and fulfilled.
        :param pulumi.Input[_builtins.str] created: The date and time when the request condition was created.
        :param pulumi.Input[_builtins.str] created_by: The id of the user who created the request condition.
        :param pulumi.Input[_builtins.str] grant_status: The status of the granted access request.
        :param pulumi.Input[_builtins.str] granted: The date the approved access was granted. Only set if request . Status is APPROVED.
        :param pulumi.Input[_builtins.str] last_updated: The date and time when the request condition was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of the user who last updated the request condition.
        :param pulumi.Input[Union['RequestV2RequestedArgs', 'RequestV2RequestedArgsDict']] requested: A representation of a resource that can be requested for access.
        :param pulumi.Input[Union['RequestV2RequestedForArgs', 'RequestV2RequestedForArgsDict']] requested_for: A representation of a principal.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RequestV2RequesterFieldValueArgs', 'RequestV2RequesterFieldValueArgsDict']]]] requester_field_values: The requester input fields required by the approval system.
        :param pulumi.Input[_builtins.str] resolved: The date the request was resolved.
        :param pulumi.Input[_builtins.str] revocation_scheduled: The date the request was scheduled for revocation.
        :param pulumi.Input[_builtins.str] revocation_status: The revocation status of the request.
        :param pulumi.Input[_builtins.str] revoked: The date the granted access was revoked.
        :param pulumi.Input[_builtins.str] status: The status of the request.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestV2State.__new__(_RequestV2State)

        __props__.__dict__["access_duration"] = access_duration
        __props__.__dict__["created"] = created
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["grant_status"] = grant_status
        __props__.__dict__["granted"] = granted
        __props__.__dict__["last_updated"] = last_updated
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["requested"] = requested
        __props__.__dict__["requested_for"] = requested_for
        __props__.__dict__["requester_field_values"] = requester_field_values
        __props__.__dict__["resolved"] = resolved
        __props__.__dict__["revocation_scheduled"] = revocation_scheduled
        __props__.__dict__["revocation_status"] = revocation_status
        __props__.__dict__["revoked"] = revoked
        __props__.__dict__["status"] = status
        return RequestV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessDuration")
    def access_duration(self) -> pulumi.Output[_builtins.str]:
        """
        How long the requester retains access after their request is approved and fulfilled.
        """
        return pulumi.get(self, "access_duration")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the request condition was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the user who created the request condition.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="grantStatus")
    def grant_status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the granted access request.
        """
        return pulumi.get(self, "grant_status")

    @_builtins.property
    @pulumi.getter
    def granted(self) -> pulumi.Output[_builtins.str]:
        """
        The date the approved access was granted. Only set if request . Status is APPROVED.
        """
        return pulumi.get(self, "granted")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the request condition was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the user who last updated the request condition.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def requested(self) -> pulumi.Output[Optional['outputs.RequestV2Requested']]:
        """
        A representation of a resource that can be requested for access.
        """
        return pulumi.get(self, "requested")

    @_builtins.property
    @pulumi.getter(name="requestedFor")
    def requested_for(self) -> pulumi.Output[Optional['outputs.RequestV2RequestedFor']]:
        """
        A representation of a principal.
        """
        return pulumi.get(self, "requested_for")

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> pulumi.Output[Optional[Sequence['outputs.RequestV2RequesterFieldValue']]]:
        """
        The requester input fields required by the approval system.
        """
        return pulumi.get(self, "requester_field_values")

    @_builtins.property
    @pulumi.getter
    def resolved(self) -> pulumi.Output[_builtins.str]:
        """
        The date the request was resolved.
        """
        return pulumi.get(self, "resolved")

    @_builtins.property
    @pulumi.getter(name="revocationScheduled")
    def revocation_scheduled(self) -> pulumi.Output[_builtins.str]:
        """
        The date the request was scheduled for revocation.
        """
        return pulumi.get(self, "revocation_scheduled")

    @_builtins.property
    @pulumi.getter(name="revocationStatus")
    def revocation_status(self) -> pulumi.Output[_builtins.str]:
        """
        The revocation status of the request.
        """
        return pulumi.get(self, "revocation_status")

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> pulumi.Output[_builtins.str]:
        """
        The date the granted access was revoked.
        """
        return pulumi.get(self, "revoked")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the request.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOauthResult',
    'AwaitableGetOauthResult',
    'get_oauth',
    'get_oauth_output',
]

@pulumi.output_type
class GetOauthResult:
    """
    A collection of values returned by getOauth.
    """
    def __init__(__self__, active_only=None, auto_submit_toolbar=None, client_id=None, client_secret=None, client_uri=None, grant_types=None, hide_ios=None, hide_web=None, id=None, label=None, label_prefix=None, links=None, login_mode=None, login_scopes=None, login_uri=None, logo_uri=None, name=None, policy_uri=None, post_logout_redirect_uris=None, redirect_uris=None, response_types=None, skip_groups=None, skip_users=None, status=None, type=None, wildcard_redirect=None):
        if active_only and not isinstance(active_only, bool):
            raise TypeError("Expected argument 'active_only' to be a bool")
        pulumi.set(__self__, "active_only", active_only)
        if auto_submit_toolbar and not isinstance(auto_submit_toolbar, bool):
            raise TypeError("Expected argument 'auto_submit_toolbar' to be a bool")
        pulumi.set(__self__, "auto_submit_toolbar", auto_submit_toolbar)
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if client_secret and not isinstance(client_secret, str):
            raise TypeError("Expected argument 'client_secret' to be a str")
        pulumi.set(__self__, "client_secret", client_secret)
        if client_uri and not isinstance(client_uri, str):
            raise TypeError("Expected argument 'client_uri' to be a str")
        pulumi.set(__self__, "client_uri", client_uri)
        if grant_types and not isinstance(grant_types, list):
            raise TypeError("Expected argument 'grant_types' to be a list")
        pulumi.set(__self__, "grant_types", grant_types)
        if hide_ios and not isinstance(hide_ios, bool):
            raise TypeError("Expected argument 'hide_ios' to be a bool")
        pulumi.set(__self__, "hide_ios", hide_ios)
        if hide_web and not isinstance(hide_web, bool):
            raise TypeError("Expected argument 'hide_web' to be a bool")
        pulumi.set(__self__, "hide_web", hide_web)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if label_prefix and not isinstance(label_prefix, str):
            raise TypeError("Expected argument 'label_prefix' to be a str")
        pulumi.set(__self__, "label_prefix", label_prefix)
        if links and not isinstance(links, str):
            raise TypeError("Expected argument 'links' to be a str")
        pulumi.set(__self__, "links", links)
        if login_mode and not isinstance(login_mode, str):
            raise TypeError("Expected argument 'login_mode' to be a str")
        pulumi.set(__self__, "login_mode", login_mode)
        if login_scopes and not isinstance(login_scopes, list):
            raise TypeError("Expected argument 'login_scopes' to be a list")
        pulumi.set(__self__, "login_scopes", login_scopes)
        if login_uri and not isinstance(login_uri, str):
            raise TypeError("Expected argument 'login_uri' to be a str")
        pulumi.set(__self__, "login_uri", login_uri)
        if logo_uri and not isinstance(logo_uri, str):
            raise TypeError("Expected argument 'logo_uri' to be a str")
        pulumi.set(__self__, "logo_uri", logo_uri)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if policy_uri and not isinstance(policy_uri, str):
            raise TypeError("Expected argument 'policy_uri' to be a str")
        pulumi.set(__self__, "policy_uri", policy_uri)
        if post_logout_redirect_uris and not isinstance(post_logout_redirect_uris, list):
            raise TypeError("Expected argument 'post_logout_redirect_uris' to be a list")
        pulumi.set(__self__, "post_logout_redirect_uris", post_logout_redirect_uris)
        if redirect_uris and not isinstance(redirect_uris, list):
            raise TypeError("Expected argument 'redirect_uris' to be a list")
        pulumi.set(__self__, "redirect_uris", redirect_uris)
        if response_types and not isinstance(response_types, list):
            raise TypeError("Expected argument 'response_types' to be a list")
        pulumi.set(__self__, "response_types", response_types)
        if skip_groups and not isinstance(skip_groups, bool):
            raise TypeError("Expected argument 'skip_groups' to be a bool")
        pulumi.set(__self__, "skip_groups", skip_groups)
        if skip_users and not isinstance(skip_users, bool):
            raise TypeError("Expected argument 'skip_users' to be a bool")
        pulumi.set(__self__, "skip_users", skip_users)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if wildcard_redirect and not isinstance(wildcard_redirect, str):
            raise TypeError("Expected argument 'wildcard_redirect' to be a str")
        pulumi.set(__self__, "wildcard_redirect", wildcard_redirect)

    @_builtins.property
    @pulumi.getter(name="activeOnly")
    def active_only(self) -> Optional[_builtins.bool]:
        """
        Search only ACTIVE applications.
        """
        return pulumi.get(self, "active_only")

    @_builtins.property
    @pulumi.getter(name="autoSubmitToolbar")
    def auto_submit_toolbar(self) -> _builtins.bool:
        """
        Display auto submit toolbar
        """
        return pulumi.get(self, "auto_submit_toolbar")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> _builtins.str:
        """
        OAuth client ID
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> _builtins.str:
        """
        OAuth client secret
        """
        return pulumi.get(self, "client_secret")

    @_builtins.property
    @pulumi.getter(name="clientUri")
    def client_uri(self) -> _builtins.str:
        """
        URI to a web page providing information about the client.
        """
        return pulumi.get(self, "client_uri")

    @_builtins.property
    @pulumi.getter(name="grantTypes")
    def grant_types(self) -> Sequence[_builtins.str]:
        """
        List of OAuth 2.0 grant types
        """
        return pulumi.get(self, "grant_types")

    @_builtins.property
    @pulumi.getter(name="hideIos")
    def hide_ios(self) -> _builtins.bool:
        """
        Do not display application icon on mobile app
        """
        return pulumi.get(self, "hide_ios")

    @_builtins.property
    @pulumi.getter(name="hideWeb")
    def hide_web(self) -> _builtins.bool:
        """
        Do not display application icon to users
        """
        return pulumi.get(self, "hide_web")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Id of application to retrieve, conflicts with label and label_prefix.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[_builtins.str]:
        """
        The label of the app to retrieve, conflicts with
        			label_prefix and id. Label uses the ?q=\\n\\n query parameter exposed by
        			Okta's List Apps API. The API will search both name and label using that
        			query. Therefore similarily named and labeled apps may be returned in the query
        			and have the unitended result of associating the wrong app with this data
        			source. See:
        			https://developer.okta.com/docs/reference/api/apps/#list-applications
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="labelPrefix")
    def label_prefix(self) -> Optional[_builtins.str]:
        """
        Label prefix of the app to retrieve, conflicts with label and id. This will tell the
        			provider to do a starts with query as opposed to an equals query.
        """
        return pulumi.get(self, "label_prefix")

    @_builtins.property
    @pulumi.getter
    def links(self) -> _builtins.str:
        """
        Discoverable resources related to the app
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter(name="loginMode")
    def login_mode(self) -> _builtins.str:
        """
        The type of Idp-Initiated login that the client supports, if any
        """
        return pulumi.get(self, "login_mode")

    @_builtins.property
    @pulumi.getter(name="loginScopes")
    def login_scopes(self) -> Sequence[_builtins.str]:
        """
        List of scopes to use for the request when 'login_mode' == OKTA
        """
        return pulumi.get(self, "login_scopes")

    @_builtins.property
    @pulumi.getter(name="loginUri")
    def login_uri(self) -> _builtins.str:
        """
        URI that initiates login.
        """
        return pulumi.get(self, "login_uri")

    @_builtins.property
    @pulumi.getter(name="logoUri")
    def logo_uri(self) -> _builtins.str:
        """
        URI that references a logo for the client.
        """
        return pulumi.get(self, "logo_uri")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of application.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="policyUri")
    def policy_uri(self) -> _builtins.str:
        """
        URI to web page providing client policy document.
        """
        return pulumi.get(self, "policy_uri")

    @_builtins.property
    @pulumi.getter(name="postLogoutRedirectUris")
    def post_logout_redirect_uris(self) -> Sequence[_builtins.str]:
        """
        List of URIs for redirection after logout
        """
        return pulumi.get(self, "post_logout_redirect_uris")

    @_builtins.property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> Sequence[_builtins.str]:
        """
        List of URIs for use in the redirect-based flow.
        """
        return pulumi.get(self, "redirect_uris")

    @_builtins.property
    @pulumi.getter(name="responseTypes")
    def response_types(self) -> Sequence[_builtins.str]:
        """
        List of OAuth 2.0 response type strings.
        """
        return pulumi.get(self, "response_types")

    @_builtins.property
    @pulumi.getter(name="skipGroups")
    @_utilities.deprecated("""Because groups has been removed, this attribute is a no op and will be removed""")
    def skip_groups(self) -> Optional[_builtins.bool]:
        """
        Ignore groups sync. This is a temporary solution until 'groups' field is supported in all the app-like resources
        """
        return pulumi.get(self, "skip_groups")

    @_builtins.property
    @pulumi.getter(name="skipUsers")
    @_utilities.deprecated("""Because users has been removed, this attribute is a no op and will be removed""")
    def skip_users(self) -> Optional[_builtins.bool]:
        """
        Ignore users sync. This is a temporary solution until 'users' field is supported in all the app-like resources
        """
        return pulumi.get(self, "skip_users")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of application.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of OAuth application.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="wildcardRedirect")
    def wildcard_redirect(self) -> _builtins.str:
        """
        Indicates if the client is allowed to use wildcard matching of redirect_uris. Some valid values include: "SUBDOMAIN", "DISABLED".
        """
        return pulumi.get(self, "wildcard_redirect")


class AwaitableGetOauthResult(GetOauthResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOauthResult(
            active_only=self.active_only,
            auto_submit_toolbar=self.auto_submit_toolbar,
            client_id=self.client_id,
            client_secret=self.client_secret,
            client_uri=self.client_uri,
            grant_types=self.grant_types,
            hide_ios=self.hide_ios,
            hide_web=self.hide_web,
            id=self.id,
            label=self.label,
            label_prefix=self.label_prefix,
            links=self.links,
            login_mode=self.login_mode,
            login_scopes=self.login_scopes,
            login_uri=self.login_uri,
            logo_uri=self.logo_uri,
            name=self.name,
            policy_uri=self.policy_uri,
            post_logout_redirect_uris=self.post_logout_redirect_uris,
            redirect_uris=self.redirect_uris,
            response_types=self.response_types,
            skip_groups=self.skip_groups,
            skip_users=self.skip_users,
            status=self.status,
            type=self.type,
            wildcard_redirect=self.wildcard_redirect)


def get_oauth(active_only: Optional[_builtins.bool] = None,
              id: Optional[_builtins.str] = None,
              label: Optional[_builtins.str] = None,
              label_prefix: Optional[_builtins.str] = None,
              skip_groups: Optional[_builtins.bool] = None,
              skip_users: Optional[_builtins.bool] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOauthResult:
    """
    Get a OIDC application from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.app.get_oauth(label="Example App")
    ```


    :param _builtins.bool active_only: Search only ACTIVE applications.
    :param _builtins.str id: Id of application to retrieve, conflicts with label and label_prefix.
    :param _builtins.str label: The label of the app to retrieve, conflicts with
           			label_prefix and id. Label uses the ?q=\\n\\n query parameter exposed by
           			Okta's List Apps API. The API will search both name and label using that
           			query. Therefore similarily named and labeled apps may be returned in the query
           			and have the unitended result of associating the wrong app with this data
           			source. See:
           			https://developer.okta.com/docs/reference/api/apps/#list-applications
    :param _builtins.str label_prefix: Label prefix of the app to retrieve, conflicts with label and id. This will tell the
           			provider to do a starts with query as opposed to an equals query.
    :param _builtins.bool skip_groups: Ignore groups sync. This is a temporary solution until 'groups' field is supported in all the app-like resources
    :param _builtins.bool skip_users: Ignore users sync. This is a temporary solution until 'users' field is supported in all the app-like resources
    """
    __args__ = dict()
    __args__['activeOnly'] = active_only
    __args__['id'] = id
    __args__['label'] = label
    __args__['labelPrefix'] = label_prefix
    __args__['skipGroups'] = skip_groups
    __args__['skipUsers'] = skip_users
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:app/getOauth:getOauth', __args__, opts=opts, typ=GetOauthResult).value

    return AwaitableGetOauthResult(
        active_only=pulumi.get(__ret__, 'active_only'),
        auto_submit_toolbar=pulumi.get(__ret__, 'auto_submit_toolbar'),
        client_id=pulumi.get(__ret__, 'client_id'),
        client_secret=pulumi.get(__ret__, 'client_secret'),
        client_uri=pulumi.get(__ret__, 'client_uri'),
        grant_types=pulumi.get(__ret__, 'grant_types'),
        hide_ios=pulumi.get(__ret__, 'hide_ios'),
        hide_web=pulumi.get(__ret__, 'hide_web'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        label_prefix=pulumi.get(__ret__, 'label_prefix'),
        links=pulumi.get(__ret__, 'links'),
        login_mode=pulumi.get(__ret__, 'login_mode'),
        login_scopes=pulumi.get(__ret__, 'login_scopes'),
        login_uri=pulumi.get(__ret__, 'login_uri'),
        logo_uri=pulumi.get(__ret__, 'logo_uri'),
        name=pulumi.get(__ret__, 'name'),
        policy_uri=pulumi.get(__ret__, 'policy_uri'),
        post_logout_redirect_uris=pulumi.get(__ret__, 'post_logout_redirect_uris'),
        redirect_uris=pulumi.get(__ret__, 'redirect_uris'),
        response_types=pulumi.get(__ret__, 'response_types'),
        skip_groups=pulumi.get(__ret__, 'skip_groups'),
        skip_users=pulumi.get(__ret__, 'skip_users'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'),
        wildcard_redirect=pulumi.get(__ret__, 'wildcard_redirect'))
def get_oauth_output(active_only: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     label: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     label_prefix: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     skip_groups: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     skip_users: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOauthResult]:
    """
    Get a OIDC application from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.app.get_oauth(label="Example App")
    ```


    :param _builtins.bool active_only: Search only ACTIVE applications.
    :param _builtins.str id: Id of application to retrieve, conflicts with label and label_prefix.
    :param _builtins.str label: The label of the app to retrieve, conflicts with
           			label_prefix and id. Label uses the ?q=\\n\\n query parameter exposed by
           			Okta's List Apps API. The API will search both name and label using that
           			query. Therefore similarily named and labeled apps may be returned in the query
           			and have the unitended result of associating the wrong app with this data
           			source. See:
           			https://developer.okta.com/docs/reference/api/apps/#list-applications
    :param _builtins.str label_prefix: Label prefix of the app to retrieve, conflicts with label and id. This will tell the
           			provider to do a starts with query as opposed to an equals query.
    :param _builtins.bool skip_groups: Ignore groups sync. This is a temporary solution until 'groups' field is supported in all the app-like resources
    :param _builtins.bool skip_users: Ignore users sync. This is a temporary solution until 'users' field is supported in all the app-like resources
    """
    __args__ = dict()
    __args__['activeOnly'] = active_only
    __args__['id'] = id
    __args__['label'] = label
    __args__['labelPrefix'] = label_prefix
    __args__['skipGroups'] = skip_groups
    __args__['skipUsers'] = skip_users
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:app/getOauth:getOauth', __args__, opts=opts, typ=GetOauthResult)
    return __ret__.apply(lambda __response__: GetOauthResult(
        active_only=pulumi.get(__response__, 'active_only'),
        auto_submit_toolbar=pulumi.get(__response__, 'auto_submit_toolbar'),
        client_id=pulumi.get(__response__, 'client_id'),
        client_secret=pulumi.get(__response__, 'client_secret'),
        client_uri=pulumi.get(__response__, 'client_uri'),
        grant_types=pulumi.get(__response__, 'grant_types'),
        hide_ios=pulumi.get(__response__, 'hide_ios'),
        hide_web=pulumi.get(__response__, 'hide_web'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        label_prefix=pulumi.get(__response__, 'label_prefix'),
        links=pulumi.get(__response__, 'links'),
        login_mode=pulumi.get(__response__, 'login_mode'),
        login_scopes=pulumi.get(__response__, 'login_scopes'),
        login_uri=pulumi.get(__response__, 'login_uri'),
        logo_uri=pulumi.get(__response__, 'logo_uri'),
        name=pulumi.get(__response__, 'name'),
        policy_uri=pulumi.get(__response__, 'policy_uri'),
        post_logout_redirect_uris=pulumi.get(__response__, 'post_logout_redirect_uris'),
        redirect_uris=pulumi.get(__response__, 'redirect_uris'),
        response_types=pulumi.get(__response__, 'response_types'),
        skip_groups=pulumi.get(__response__, 'skip_groups'),
        skip_users=pulumi.get(__response__, 'skip_users'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type'),
        wildcard_redirect=pulumi.get(__response__, 'wildcard_redirect')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCampaignResult',
    'AwaitableGetCampaignResult',
    'get_campaign',
    'get_campaign_output',
]

@pulumi.output_type
class GetCampaignResult:
    """
    A collection of values returned by getCampaign.
    """
    def __init__(__self__, campaign_type=None, created=None, created_by=None, description=None, id=None, last_updated=None, last_updated_by=None, name=None, notification_settings=None, principal_scope_settings=None, recurring_campaign_id=None, remediation_settings=None, resource_settings=None, reviewer_settings=None, schedule_settings=None, status=None):
        if campaign_type and not isinstance(campaign_type, str):
            raise TypeError("Expected argument 'campaign_type' to be a str")
        pulumi.set(__self__, "campaign_type", campaign_type)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_settings and not isinstance(notification_settings, dict):
            raise TypeError("Expected argument 'notification_settings' to be a dict")
        pulumi.set(__self__, "notification_settings", notification_settings)
        if principal_scope_settings and not isinstance(principal_scope_settings, dict):
            raise TypeError("Expected argument 'principal_scope_settings' to be a dict")
        pulumi.set(__self__, "principal_scope_settings", principal_scope_settings)
        if recurring_campaign_id and not isinstance(recurring_campaign_id, str):
            raise TypeError("Expected argument 'recurring_campaign_id' to be a str")
        pulumi.set(__self__, "recurring_campaign_id", recurring_campaign_id)
        if remediation_settings and not isinstance(remediation_settings, dict):
            raise TypeError("Expected argument 'remediation_settings' to be a dict")
        pulumi.set(__self__, "remediation_settings", remediation_settings)
        if resource_settings and not isinstance(resource_settings, dict):
            raise TypeError("Expected argument 'resource_settings' to be a dict")
        pulumi.set(__self__, "resource_settings", resource_settings)
        if reviewer_settings and not isinstance(reviewer_settings, dict):
            raise TypeError("Expected argument 'reviewer_settings' to be a dict")
        pulumi.set(__self__, "reviewer_settings", reviewer_settings)
        if schedule_settings and not isinstance(schedule_settings, dict):
            raise TypeError("Expected argument 'schedule_settings' to be a dict")
        pulumi.set(__self__, "schedule_settings", schedule_settings)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="campaignType")
    def campaign_type(self) -> _builtins.str:
        return pulumi.get(self, "campaign_type")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional['outputs.GetCampaignNotificationSettingsResult']:
        return pulumi.get(self, "notification_settings")

    @_builtins.property
    @pulumi.getter(name="principalScopeSettings")
    def principal_scope_settings(self) -> Optional['outputs.GetCampaignPrincipalScopeSettingsResult']:
        return pulumi.get(self, "principal_scope_settings")

    @_builtins.property
    @pulumi.getter(name="recurringCampaignId")
    def recurring_campaign_id(self) -> _builtins.str:
        return pulumi.get(self, "recurring_campaign_id")

    @_builtins.property
    @pulumi.getter(name="remediationSettings")
    def remediation_settings(self) -> Optional['outputs.GetCampaignRemediationSettingsResult']:
        return pulumi.get(self, "remediation_settings")

    @_builtins.property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> Optional['outputs.GetCampaignResourceSettingsResult']:
        return pulumi.get(self, "resource_settings")

    @_builtins.property
    @pulumi.getter(name="reviewerSettings")
    def reviewer_settings(self) -> Optional['outputs.GetCampaignReviewerSettingsResult']:
        return pulumi.get(self, "reviewer_settings")

    @_builtins.property
    @pulumi.getter(name="scheduleSettings")
    def schedule_settings(self) -> Optional['outputs.GetCampaignScheduleSettingsResult']:
        return pulumi.get(self, "schedule_settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        return pulumi.get(self, "status")


class AwaitableGetCampaignResult(GetCampaignResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCampaignResult(
            campaign_type=self.campaign_type,
            created=self.created,
            created_by=self.created_by,
            description=self.description,
            id=self.id,
            last_updated=self.last_updated,
            last_updated_by=self.last_updated_by,
            name=self.name,
            notification_settings=self.notification_settings,
            principal_scope_settings=self.principal_scope_settings,
            recurring_campaign_id=self.recurring_campaign_id,
            remediation_settings=self.remediation_settings,
            resource_settings=self.resource_settings,
            reviewer_settings=self.reviewer_settings,
            schedule_settings=self.schedule_settings,
            status=self.status)


def get_campaign(campaign_type: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None,
                 id: Optional[_builtins.str] = None,
                 notification_settings: Optional[Union['GetCampaignNotificationSettingsArgs', 'GetCampaignNotificationSettingsArgsDict']] = None,
                 principal_scope_settings: Optional[Union['GetCampaignPrincipalScopeSettingsArgs', 'GetCampaignPrincipalScopeSettingsArgsDict']] = None,
                 remediation_settings: Optional[Union['GetCampaignRemediationSettingsArgs', 'GetCampaignRemediationSettingsArgsDict']] = None,
                 resource_settings: Optional[Union['GetCampaignResourceSettingsArgs', 'GetCampaignResourceSettingsArgsDict']] = None,
                 reviewer_settings: Optional[Union['GetCampaignReviewerSettingsArgs', 'GetCampaignReviewerSettingsArgsDict']] = None,
                 schedule_settings: Optional[Union['GetCampaignScheduleSettingsArgs', 'GetCampaignScheduleSettingsArgsDict']] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCampaignResult:
    """
    Get the campaign belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_campaign(id="<campaign id>")
    ```


    :param _builtins.str id: The ID of this resource.
    """
    __args__ = dict()
    __args__['campaignType'] = campaign_type
    __args__['description'] = description
    __args__['id'] = id
    __args__['notificationSettings'] = notification_settings
    __args__['principalScopeSettings'] = principal_scope_settings
    __args__['remediationSettings'] = remediation_settings
    __args__['resourceSettings'] = resource_settings
    __args__['reviewerSettings'] = reviewer_settings
    __args__['scheduleSettings'] = schedule_settings
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getCampaign:getCampaign', __args__, opts=opts, typ=GetCampaignResult).value

    return AwaitableGetCampaignResult(
        campaign_type=pulumi.get(__ret__, 'campaign_type'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        name=pulumi.get(__ret__, 'name'),
        notification_settings=pulumi.get(__ret__, 'notification_settings'),
        principal_scope_settings=pulumi.get(__ret__, 'principal_scope_settings'),
        recurring_campaign_id=pulumi.get(__ret__, 'recurring_campaign_id'),
        remediation_settings=pulumi.get(__ret__, 'remediation_settings'),
        resource_settings=pulumi.get(__ret__, 'resource_settings'),
        reviewer_settings=pulumi.get(__ret__, 'reviewer_settings'),
        schedule_settings=pulumi.get(__ret__, 'schedule_settings'),
        status=pulumi.get(__ret__, 'status'))
def get_campaign_output(campaign_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        notification_settings: Optional[pulumi.Input[Optional[Union['GetCampaignNotificationSettingsArgs', 'GetCampaignNotificationSettingsArgsDict']]]] = None,
                        principal_scope_settings: Optional[pulumi.Input[Optional[Union['GetCampaignPrincipalScopeSettingsArgs', 'GetCampaignPrincipalScopeSettingsArgsDict']]]] = None,
                        remediation_settings: Optional[pulumi.Input[Optional[Union['GetCampaignRemediationSettingsArgs', 'GetCampaignRemediationSettingsArgsDict']]]] = None,
                        resource_settings: Optional[pulumi.Input[Optional[Union['GetCampaignResourceSettingsArgs', 'GetCampaignResourceSettingsArgsDict']]]] = None,
                        reviewer_settings: Optional[pulumi.Input[Optional[Union['GetCampaignReviewerSettingsArgs', 'GetCampaignReviewerSettingsArgsDict']]]] = None,
                        schedule_settings: Optional[pulumi.Input[Optional[Union['GetCampaignScheduleSettingsArgs', 'GetCampaignScheduleSettingsArgsDict']]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCampaignResult]:
    """
    Get the campaign belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_campaign(id="<campaign id>")
    ```


    :param _builtins.str id: The ID of this resource.
    """
    __args__ = dict()
    __args__['campaignType'] = campaign_type
    __args__['description'] = description
    __args__['id'] = id
    __args__['notificationSettings'] = notification_settings
    __args__['principalScopeSettings'] = principal_scope_settings
    __args__['remediationSettings'] = remediation_settings
    __args__['resourceSettings'] = resource_settings
    __args__['reviewerSettings'] = reviewer_settings
    __args__['scheduleSettings'] = schedule_settings
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getCampaign:getCampaign', __args__, opts=opts, typ=GetCampaignResult)
    return __ret__.apply(lambda __response__: GetCampaignResult(
        campaign_type=pulumi.get(__response__, 'campaign_type'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        name=pulumi.get(__response__, 'name'),
        notification_settings=pulumi.get(__response__, 'notification_settings'),
        principal_scope_settings=pulumi.get(__response__, 'principal_scope_settings'),
        recurring_campaign_id=pulumi.get(__response__, 'recurring_campaign_id'),
        remediation_settings=pulumi.get(__response__, 'remediation_settings'),
        resource_settings=pulumi.get(__response__, 'resource_settings'),
        reviewer_settings=pulumi.get(__response__, 'reviewer_settings'),
        schedule_settings=pulumi.get(__response__, 'schedule_settings'),
        status=pulumi.get(__response__, 'status')))
